// Copyright (c) 2017, Marty Mills <daggerbot@gmail.com>
// This software is available under the terms of the zlib license.
// See COPYING.md for more information.

use config::{Config, ConfigInfo, Configs};
use context::ContextBuilder;
use error::Result;

/// Extension traits for `dwindow::Display`.
pub trait DisplayExt {
    fn gl_configs (&self) -> Result<Configs>;
    fn gles_configs (&self) -> Result<Configs>;
    fn new_gl_context (&self) -> ContextBuilder;
    fn new_gles_context (&self) -> ContextBuilder;

    fn choose_gl_config (&self, spec: &ConfigInfo) -> Result<Config> {
        self.gl_configs()?.choose(spec)
    }

    fn choose_gles_config (&self, spec: &ConfigInfo) -> Result<Config> {
        self.gles_configs()?.choose(spec)
    }

    fn default_gl_config (&self) -> Result<Config> {
        self.choose_gl_config(&ConfigInfo::default())
    }

    fn default_gles_config (&self) -> Result<Config> {
        self.choose_gles_config(&ConfigInfo::default())
    }
}
