// Copyright (c) 2017, Marty Mills <daggerbot@gmail.com>
// This software is available under the terms of the zlib license.
// See COPYING.md for more information.

use dwindow::Display;

use config::Configs;
use context::{Api, ContextBuilder};
use display::DisplayExt;
use error::Result;
use provider::glx::ConfigsProvider;

impl DisplayExt for Display {
    fn gl_configs (&self) -> Result<Configs> {
        Ok(Configs::from_provider(ConfigsProvider::gl_configs(self)?))
    }

    fn gles_configs (&self) -> Result<Configs> {
        Err(err!(Unimplemented).with_str("OpenGL ES under X11"))
    }

    fn new_gl_context (&self) -> ContextBuilder {
        ContextBuilder::new(self, Api::Opengl)
    }

    fn new_gles_context (&self) -> ContextBuilder {
        ContextBuilder::new(self, Api::Opengles)
    }
}
