// Copyright (c) 2017, Marty Mills <daggerbot@gmail.com>
// This software is available under the terms of the zlib license.
// See COPYING.md for more information.

pub mod config;
pub mod context;
pub mod display;
pub mod surface;

use std::sync::Arc;

use x11::glx;

use error::Result;

pub use self::config::{ConfigProvider, ConfigsProvider};
pub use self::context::{ContextProvider, CurrentProvider};

/// Opens a global GLX instance.
fn open_glx () -> Result<Arc<glx::Glx>> {
    lazy_static! {
        static ref LIB: Result<Arc<glx::Glx>> = match glx::Glx::open() {
            Ok(lib) => Ok(Arc::new(lib)),
            Err(err) => Err(err!(LibraryError).with_str("glx").with_cause(err)),
        };
    }

    LIB.clone()
}
