// Copyright (c) 2017, Marty Mills <daggerbot@gmail.com>
// This software is available under the terms of the zlib license.
// See COPYING.md for more information.

use std::rc::Rc;

use dwindow::sys::freedesktop::WindowExt as _WindowExt0;
use dwindow::sys::x11::Connection;
use x11::xlib;

use error::Result;
use surface::SurfaceRef;

/// Extensions for `SurfaceRef`.
pub trait SurfaceRefExt<'a> {
    fn try_connection (self) -> Result<&'a Rc<Connection>>;
    fn try_xid (self) -> Result<xlib::Drawable>;
}

impl<'a> SurfaceRefExt<'a> for SurfaceRef<'a> {
    fn try_connection (self) -> Result<&'a Rc<Connection>> {
        match self {
            SurfaceRef::Window(w) => Ok(w.as_raw().try_x11()?.connection),
        }
    }

    fn try_xid (self) -> Result<xlib::Drawable> {
        match self {
            SurfaceRef::Window(w) => w.as_raw().try_x11()?.try_xid(),
        }
    }
}
